# IOTile Core
A python package for interacting with IOTile based devices.

## Installation

```
pip install iotile-core
```

## Copyright and license
This code is adapted from code and documentation copyright 2015 WellDone
International as pymomo. The IOTile library is released under the
[LGPLv3](https://www.gnu.org/licenses/lgpl.html) Open Source license.  See the
LICENSE file.

`iotile-core` embeds version 1.5 of the
[intelhex](http://pythonhosted.org/IntelHex/) package.  The `intelhex` code
retains its original BSD license, which [allows for embedded
redistribution](http://pythonhosted.org/IntelHex/part4.html#embedding-into-
other-projects).
